@@ -22,8 +22,8 @@ from neutron.agent.l3 import ha
 from neutron.agent.l3 import router_info
 from neutron.agent.linux import interface
 from neutron.common import config as base_config
-from neutron.common import constants as l3_constants
 from neutron.tests import base
+from neutron_lib import constants as l3_constants
 from oslo_utils import uuidutils
 
 from neutron_fwaas.services.firewall.agents.varmour import varmour_router
@@ -44,7 +44,6 @@ class TestBasicRouterOperations(base.BaseTestCase):
         self.conf.register_opts(ha.OPTS)
         agent_config.register_process_monitor_opts(self.conf)
         agent_config.register_interface_driver_opts_helper(self.conf)
-        agent_config.register_use_namespaces_opts_helper(self.conf)
         self.conf.register_opts(interface.OPTS)
         self.conf.set_override('interface_driver',
                                'neutron.agent.linux.interface.NullDriver')
